[chronojump] minor change



commit 68c6288fe8b3dcb2ccaf5503855e925912081705
Author: Xavier de Blas <xaviblas gmail com>
Date:   Tue Jul 27 13:57:40 2021 +0200

    minor change

 src/gui/networks.cs   | 4 ++--
 src/json/compujump.cs | 8 ++++----
 2 files changed, 6 insertions(+), 6 deletions(-)
---
diff --git a/src/gui/networks.cs b/src/gui/networks.cs
index e1550dc49..c124326ce 100644
--- a/src/gui/networks.cs
+++ b/src/gui/networks.cs
@@ -706,7 +706,7 @@ public partial class ChronoJumpWindow
                                //check if this uniqueID already exists on local database (would mean RFID 
changed on server)
                                pLocal = SqlitePerson.Select(false, pServer.UniqueID);
 
-                               if(! json.LastPersonWasInserted)
+                               if(! json.LastPersonJustInserted)
                                {
                                        /*
                                         * id exists locally, RFID has changed. Changed locally
@@ -724,7 +724,7 @@ public partial class ChronoJumpWindow
                                currentPerson = pLocal;
                                insertAndAssignPersonSessionIfNeeded(json);
 
-                               if(json.LastPersonWasInserted)
+                               if(json.LastPersonJustInserted)
                                {
                                        compujumpDownloadImage (json, json.LastPersonByRFIDImageURL, 
currentPerson.UniqueID);
                                        person_added(); //GTK
diff --git a/src/json/compujump.cs b/src/json/compujump.cs
index 06054be9d..ac80fae07 100644
--- a/src/json/compujump.cs
+++ b/src/json/compujump.cs
@@ -99,7 +99,7 @@ public class JsonCompujump : Json
        public double LastPersonByRFIDHeight = 0;
        public double LastPersonByRFIDWeight = 0;
        public string LastPersonByRFIDImageURL = "";
-       public bool LastPersonWasInserted = false;
+       public bool LastPersonJustInserted = false;
        private Person personDeserialize(string strPerson)
        {
                JsonValue jsonPerson = JsonValue.Parse(strPerson);
@@ -118,13 +118,13 @@ public class JsonCompujump : Json
                Person personTemp = SqlitePerson.Select(false, id);
                /*
                 * if personTemp == -1, need to insert this person
                 * LastPersonWasInserted will be used:
                 *      to insert person at person.cs
                 *      to know if (it's new person or RFID changed) at gui/networks.cs
                 */
-               LastPersonWasInserted = (personTemp.UniqueID == -1);
+               LastPersonJustInserted = (personTemp.UniqueID == -1);
 
-               return new Person(LastPersonWasInserted, id, player, rfid, image);
+               return new Person(LastPersonJustInserted, id, player, rfid, image);
        }
 
 
@@ -118,13 +118,13 @@ public class JsonCompujump : Json
                /*
                 * if personTemp == -1, need to insert this person
-                * LastPersonWasInserted will be used:
+                * LastPersonJustInserted will be used:
                 *      to insert person at person.cs
                 *      to know if (it's new person or RFID changed) at gui/networks.cs


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]